@@ -14,12 +14,14 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgis.h 9774 2008-12-12 05:41:24Z timlinux $ */
+/* $Id: qgis.h 12607 2009-12-23 22:55:10Z jef $ */
 
 #ifndef QGIS_H
 #define QGIS_H
 #include <QEvent>
 #include <QString>
+#include <cfloat>
+
 /** \ingroup core
  * The QGis class provides global constants for use throughout the application.
  */
@@ -72,13 +74,18 @@ class CORE_EXPORT QGis
     //! description strings for feature types
     static const char *qgisFeatureTypes[];
 
-    //! map units that qgis supports
+    /** Map units that qgis supports
+     * @note that QGIS < 1.4 api had only Meters, Feet, Degrees and UnknownUnit
+     */
     enum UnitType
     {
-      Meters,
-      Feet,
-      Degrees,
-      UnknownUnit
+      Meters = 0,
+      Feet = 1,
+      Degrees = 2, //for 1.0 api backwards compatibility
+      DecimalDegrees = 2,
+      DegreesMinutesSeconds = 4,
+      DegreesDecimalMinutes = 5,
+      UnknownUnit = 3
     } ;
 
     //! User defined event types
@@ -112,6 +119,15 @@ inline void ( *cast_to_fptr( void *p ) )()
   return u.f;
 }
 
+//
+// compare two doubles (but allow some difference)
+//
+inline bool doubleNear( double a, double b, double epsilon = 4 * DBL_EPSILON )
+{
+  const double diff = a - b;
+  return diff > -epsilon && diff <= epsilon;
+}
+
 /** Wkt string that represents a geographic coord sys */
 const  QString GEOWkt =
   "GEOGCS[\"WGS 84\", "
@@ -130,7 +146,7 @@ const QString GEOPROJ4 = "+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs";
 /** Magic number for a geographic coord sys in POSTGIS SRID */
 const long GEOSRID = 4326;
 /** Magic number for a geographic coord sys in QGIS srs.db tbl_srs.srs_id */
-const long GEOCRS_ID = 3344;
+const long GEOCRS_ID = 3452;
 /**  Magic number for a geographic coord sys in EpsgCrsId ID format */
 const long GEO_EPSG_CRS_ID = 4326;
 /** The length of the string "+proj=" */
