@@ -12,7 +12,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsapplication.h 9319 2008-09-13 17:42:22Z telwertowski $ */
+/* $Id: qgsapplication.h 12528 2009-12-20 12:29:07Z jef $ */
 #ifndef QGSAPPLICATION_H
 #define QGSAPPLICATION_H
 
@@ -24,6 +24,7 @@
  */
 class CORE_EXPORT QgsApplication: public QApplication
 {
+    Q_OBJECT
   public:
     QgsApplication( int & argc, char ** argv, bool GUIenabled );
     virtual ~QgsApplication();
@@ -53,9 +54,26 @@ class CORE_EXPORT QgsApplication: public QApplication
     //! Returns the path to the authors file.
     static const QString authorsFilePath();
 
-    //! Returns the path to the sponsors file.
+    /** Returns the path to the contributors file.
+     * Contributors are people who have submitted patches
+     * but don't have svn write access.
+     * @note this function was added in version 1.3 */
+    static const QString contributorsFilePath();
+
+    /**Returns the path to the sponsors file.
+      @note this function was added in version 1.2*/
     static const QString sponsorsFilePath();
 
+    /** Returns the path to the donors file.
+      @note this function was added in version 1.2*/
+    static const QString donorsFilePath();
+
+    /**
+     * Returns the path to the sponsors file.
+     * @note This was added in QGIS 1.1
+     */
+    static const QString translatorsFilePath();
+
     //! Returns the path to the developer image directory.
     static const QString developerPath();
 
@@ -86,7 +104,12 @@ class CORE_EXPORT QgsApplication: public QApplication
     //! Returns the path to the srs.db file.
     static const QString srsDbFilePath();
 
-    //! Returns the path to the svg directory.
+    //! Returns the pathes to svg directories.
+    //! @note added in 1.4
+    static const QStringList svgPaths();
+
+    //! Returns the paths to svg applications svg directory.
+    //! @note deprecated since 1.4
     static const QString svgPath();
 
     //! Returns the path to the application prefix directory.
@@ -104,6 +127,12 @@ class CORE_EXPORT QgsApplication: public QApplication
     //! Returns the path to the default theme directory.
     static const QString defaultThemePath();
 
+    //! Returns the path to user's style. Added in QGIS 1.4
+    static const QString userStyleV2Path();
+
+    //! Returns the path to default style (works as a starting point). Added in QGIS 1.4
+    static const QString defaultStyleV2Path();
+
     //! Alters prefix path - used by 3rd party apps
     static void setPrefixPath( const QString thePrefixPath, bool useDefaultPaths = FALSE );
 
