@@ -14,21 +14,24 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgscomposerview.h 9366 2008-09-21 11:48:21Z jef $ */
+/* $Id: qgscomposerview.h 12248 2009-11-25 10:17:28Z mhugent $ */
 #ifndef QGSCOMPOSERVIEW_H
 #define QGSCOMPOSERVIEW_H
 
 #include <QGraphicsView>
 
 class QKeyEvent;
+class QMainWindow;
 class QMouseEvent;
 class QgsComposition;
+class QgsComposerArrow;
 class QgsComposerItem;
 class QgsComposerLabel;
 class QgsComposerLegend;
 class QgsComposerMap;
 class QgsComposerPicture;
 class QgsComposerScaleBar;
+class QgsComposerShape;
 
 /** \ingroup MapComposer
  * \ingroup gui
@@ -47,11 +50,13 @@ class GUI_EXPORT QgsComposerView: public QGraphicsView
     enum Tool
     {
       Select = 0,      // Select/Move item
+      AddArrow,         //add arrow
       AddMap,          // add new map
       AddLegend, // add vector legend
       AddLabel,        // add label
       AddScalebar,     // add scalebar
       AddPicture,       // add raster/vector picture
+      AddShape, //add shape item (ellipse, rectangle, triangle)
       MoveItemContent //move content of item (e.g. content of map)
     };
 
@@ -71,6 +76,24 @@ class GUI_EXPORT QgsComposerView: public QGraphicsView
     /**Returns the composition or 0 in case of error*/
     QgsComposition* composition();
 
+    /**Adds an arrow item to the graphics scene and advices composer to create a widget for it (through signal)*/
+    void addComposerArrow( QgsComposerArrow* arrow );
+    /**Adds label to the graphics scene and advices composer to create a widget for it (through signal)*/
+    void addComposerLabel( QgsComposerLabel* label );
+    /**Adds map to the graphics scene and advices composer to create a widget for it (through signal)*/
+    void addComposerMap( QgsComposerMap* map );
+    /**Adds scale bar to the graphics scene and advices composer to create a widget for it (through signal)*/
+    void addComposerScaleBar( QgsComposerScaleBar* scaleBar );
+    /**Adds legend to the graphics scene and advices composer to create a widget for it (through signal)*/
+    void addComposerLegend( QgsComposerLegend* legend );
+    /**Adds picture to the graphics scene and advices composer to create a widget for it (through signal)*/
+    void addComposerPicture( QgsComposerPicture* picture );
+    /**Adds a composer shape to the graphics scene and acvices composer to create a widget for it (through signal)*/
+    void addComposerShape( QgsComposerShape* shape );
+
+    /**Returns the composer main window*/
+    QMainWindow* composerWindow();
+
   protected:
     void mousePressEvent( QMouseEvent* );
     void mouseReleaseEvent( QMouseEvent* );
@@ -88,10 +111,14 @@ class GUI_EXPORT QgsComposerView: public QGraphicsView
     QgsComposerView::Tool mCurrentTool;
     /**Rubber band item*/
     QGraphicsRectItem* mRubberBandItem;
+    /**Rubber band item for arrows*/
+    QGraphicsLineItem* mRubberBandLineItem;
     /**Item to move content*/
     QgsComposerItem* mMoveContentItem;
     /**Start position of content move*/
     QPointF mMoveContentStartPos;
+    /**Start of rubber band creation*/
+    QPointF mRubberBandStartPos;
 
   public slots:
     /**For QgsComposerItemGroup to send its signals to QgsComposer (or other classes that keep track of input widgets)*/
@@ -100,7 +127,9 @@ class GUI_EXPORT QgsComposerView: public QGraphicsView
   signals:
     /**Is emitted when selected item changed. If 0, no item is selected*/
     void selectedItemChanged( const QgsComposerItem* selected );
-    /**Ist emittted when new composer label has been added to the view*/
+    /**Is emitted when new composer arrow has been added to the view*/
+    void composerArrowAdded( QgsComposerArrow* arrow );
+    /**Is emitted when new composer label has been added to the view*/
     void composerLabelAdded( QgsComposerLabel* label );
     /**Is emitted when new composer map has been added to the view*/
     void composerMapAdded( QgsComposerMap* map );
@@ -110,6 +139,8 @@ class GUI_EXPORT QgsComposerView: public QGraphicsView
     void composerLegendAdded( QgsComposerLegend* legend );
     /**Is emitted when a new composer picture has been added*/
     void composerPictureAdded( QgsComposerPicture* picture );
+    /**Is emitted when a new composer shape has been added*/
+    void composerShapeAdded( QgsComposerShape* shape );
     /**Is emitted when a composer item has been removed from the scene*/
     void itemRemoved( QgsComposerItem* );
     /**Current action (e.g. adding composer map) has been finished. The purpose of this signal is that
