@@ -17,7 +17,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsproject.h 9536 2008-10-24 21:47:48Z timlinux $ */
+/* $Id: qgsproject.h 12350 2009-12-07 17:14:41Z wonder $ */
 
 #ifndef QGSPROJECT_H
 #define QGSPROJECT_H
@@ -25,6 +25,8 @@
 #include <memory>
 #include "qgsprojectversion.h"
 #include <QObject>
+#include <QList>
+#include <QPair>
 
 //#include <QDomDocument>
 
@@ -32,6 +34,7 @@ class QFileInfo;
 class QDomDocument;
 class QDomNode;
 
+class QgsProjectBadLayerHandler;
 
 /** \ingroup core
  * Reads and writes project states.
@@ -255,6 +258,34 @@ class CORE_EXPORT QgsProject : public QObject
     */
     void dumpProperties() const;
 
+
+    /** prepare a filename to save it to the project file
+      @note added in 1.3 */
+    QString writePath( QString filename ) const;
+
+    /** turn filename read from the project file to an absolute path
+      @note added in 1.3 */
+    QString readPath( QString filename ) const;
+
+    /** Return error message from previous read/write
+      @note added in 1.4 */
+    QString error() const;
+
+    /** Change handler for missing layers.
+      Deletes old handler and takes ownership of the new one.
+      @note added in 1.4 */
+    void setBadLayerHandler( QgsProjectBadLayerHandler* handler );
+
+  protected:
+
+    /** Set error message from read/write operation
+      @note added in 1.4 */
+    void setError( QString errorMessage );
+
+    /** Clear error message
+      @note added in 1.4 */
+    void clearError();
+
   signals:
 
     //! emitted when project is being read
@@ -266,6 +297,11 @@ class CORE_EXPORT QgsProject : public QObject
     //! emitted when an old project file is read.
     void oldProjectVersionWarning( QString );
 
+    //! emitted when a layer from a projects was read
+    // @param i current layer
+    // @param n number of layers
+    void layerLoaded( int i, int n );
+
   private:
 
     QgsProject(); // private 'cause it's a singleton
@@ -279,6 +315,32 @@ class CORE_EXPORT QgsProject : public QObject
 
     static QgsProject * theProject_;
 
+    QPair< bool, QList<QDomNode> > _getMapLayers( QDomDocument const &doc );
+
+    QString mErrorMessage;
+
+    QgsProjectBadLayerHandler* mBadLayerHandler;
+
 }; // QgsProject
 
+
+/** Interface for classes that handle missing layer files when reading project file.
+  @note added in 1.4 */
+class CORE_EXPORT QgsProjectBadLayerHandler
+{
+  public:
+    virtual void handleBadLayers( QList<QDomNode> layers, QDomDocument projectDom ) = 0;
+    virtual ~QgsProjectBadLayerHandler() {}
+};
+
+
+/** Default bad layer handler which ignores any missing layers.
+  @note added in 1.4 */
+class CORE_EXPORT QgsProjectBadLayerDefaultHandler : public QgsProjectBadLayerHandler
+{
+  public:
+    virtual void handleBadLayers( QList<QDomNode> layers, QDomDocument projectDom );
+
+};
+
 #endif
