@@ -18,7 +18,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsrasterlayer.h 10549 2009-04-13 00:42:05Z ersts $ */
+/* $Id: qgsrasterlayer.h 12600 2009-12-23 16:14:24Z jef $ */
 #ifndef QGSRASTERLAYER_H
 #define QGSRASTERLAYER_H
 
@@ -35,6 +35,7 @@
 #include "qgis.h"
 #include "qgspoint.h"
 #include "qgsmaplayer.h"
+#include "qgsrasterviewport.h"
 #include "qgscontrastenhancement.h"
 #include "qgsrastertransparency.h"
 #include "qgsrastershader.h"
@@ -59,7 +60,6 @@ class QgsRectangle;
 class QgsRasterBandStats;
 class QgsRasterPyramid;
 class QgsRasterLayerProperties;
-struct QgsRasterViewPort;
 class QImage;
 class QPixmap;
 class QSlider;
@@ -440,6 +440,12 @@ class CORE_EXPORT QgsRasterLayer : public QgsMapLayer
     /** \brief Wrapper for GDALComputeRasterMinMax with the estimate option */
     void computeMinimumMaximumEstimates( QString theBand, double* theMinMax );
 
+    /** \brief Compute the actual minimum maximum pixel values based on the current (last) display extent */
+    void computeMinimumMaximumFromLastExtent( int theBand, double* theMinMax );
+
+    /** \brief Compute the actual minimum maximum pixel values based on the current (last) display extent */
+    void computeMinimumMaximumFromLastExtent( QString theBand, double* theMinMax );
+
     /** \brief Get a pointer to the contrast enhancement for the selected band */
     QgsContrastEnhancement* contrastEnhancement( unsigned int theBand );
 
@@ -465,7 +471,7 @@ class CORE_EXPORT QgsRasterLayer : public QgsMapLayer
 
     /** \brief Returns a string representation of drawing style
      *
-     * Implementaed mainly for serialisation / deserialisation of settings to xml.
+     * Implemented mainly for serialisation / deserialisation of settings to xml.
      * NOTE: May be deprecated in the future!. DrawingStyle drawingStyle() instead.
      * */
     QString drawingStyleAsString() const;
@@ -786,7 +792,7 @@ class CORE_EXPORT QgsRasterLayer : public QgsMapLayer
 
     DrawingStyle mDrawingStyle;
 
-    /**  [ data provider interface ] Flag indicating wheter the layer is in editing mode or not*/
+    /**  [ data provider interface ] Flag indicating whether the layer is in editing mode or not*/
     bool mEditable;
 
     /** [ data provider interface ]The error message associated with the last error */
@@ -828,6 +834,8 @@ class CORE_EXPORT QgsRasterLayer : public QgsMapLayer
     /**  [ data provider interface ] Timestamp, the last modified time of the data source when the layer was created */
     QDateTime mLastModified;
 
+    QgsRasterViewPort mLastViewPort;
+
     /**  [ data provider interface ] pointer for loading the provider library */
     QLibrary* mLib;
 
