@@ -1,6 +1,7 @@
+# -*- coding: utf-8 -*-
 """
 Copyright (C) 2007-2008 Matthew Perry
-Copyright (C) 2008 Borys Jurgiel
+Copyright (C) 2008-2009 Borys Jurgiel
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -14,7 +15,7 @@ def name():
   return "Plugin Installer"
 
 def version():
-  return "Version 0.9.8"
+  return "Version 1.0.8"
 
 def description():
   return "Downloads and installs QGIS python plugins"
@@ -23,11 +24,11 @@ def qgisMinimumVersion():
   return "0.9"
 
 def authorName():
-  return "perrygeo, borysiasty"
+  return "Matthew Perry, Borys Jurgiel"
 
 def homepage():
   return "http://bwj.aster.net.pl/qgis/"
 
 def classFactory(iface):
   from installer_plugin import InstallerPlugin
-  return InstallerPlugin(iface)
\ No newline at end of file
+  return InstallerPlugin(iface)
